==> open-cluster-management-apps-model-6.9.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/SubscriptionUnitStatusFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SubscriptionUnitStatusFluent<A extends SubscriptionUnitStatusFluent<A>> extends BaseFluent<A>{
  public SubscriptionUnitStatusFluent() {
  }
  
  public SubscriptionUnitStatusFluent(SubscriptionUnitStatus instance) {
    this.copyInstance(instance);
  }
  private String lastUpdateTime;
  private String message;
  private String phase;
  private String reason;
  private Map<String,Object> resourceStatus;
  
  protected void copyInstance(SubscriptionUnitStatus instance) {
    instance = (instance != null ? instance : new SubscriptionUnitStatus());
    if (instance != null) {
          this.withLastUpdateTime(instance.getLastUpdateTime());
          this.withMessage(instance.getMessage());
          this.withPhase(instance.getPhase());
          this.withReason(instance.getReason());
          this.withResourceStatus(instance.getResourceStatus());
          this.withLastUpdateTime(instance.getLastUpdateTime());
          this.withMessage(instance.getMessage());
          this.withPhase(instance.getPhase());
          this.withReason(instance.getReason());
          this.withResourceStatus(instance.getResourceStatus());
        }
  }
  
  public String getLastUpdateTime() {
    return this.lastUpdateTime;
  }
  
  public A withLastUpdateTime(String lastUpdateTime) {
    this.lastUpdateTime = lastUpdateTime;
    return (A) this;
  }
  
  public boolean hasLastUpdateTime() {
    return this.lastUpdateTime != null;
  }
  
  public String getMessage() {
    return this.message;
  }
  
  public A withMessage(String message) {
    this.message = message;
    return (A) this;
  }
  
  public boolean hasMessage() {
    return this.message != null;
  }
  
  public String getPhase() {
    return this.phase;
  }
  
  public A withPhase(String phase) {
    this.phase = phase;
    return (A) this;
  }
  
  public boolean hasPhase() {
    return this.phase != null;
  }
  
  public String getReason() {
    return this.reason;
  }
  
  public A withReason(String reason) {
    this.reason = reason;
    return (A) this;
  }
  
  public boolean hasReason() {
    return this.reason != null;
  }
  
  public A addToResourceStatus(String key,Object value) {
    if(this.resourceStatus == null && key != null && value != null) { this.resourceStatus = new LinkedHashMap(); }
    if(key != null && value != null) {this.resourceStatus.put(key, value);} return (A)this;
  }
  
  public A addToResourceStatus(Map<String,Object> map) {
    if(this.resourceStatus == null && map != null) { this.resourceStatus = new LinkedHashMap(); }
    if(map != null) { this.resourceStatus.putAll(map);} return (A)this;
  }
  
  public A removeFromResourceStatus(String key) {
    if(this.resourceStatus == null) { return (A) this; }
    if(key != null && this.resourceStatus != null) {this.resourceStatus.remove(key);} return (A)this;
  }
  
  public A removeFromResourceStatus(Map<String,Object> map) {
    if(this.resourceStatus == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.resourceStatus != null){this.resourceStatus.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getResourceStatus() {
    return this.resourceStatus;
  }
  
  public <K,V>A withResourceStatus(Map<String,Object> resourceStatus) {
    if (resourceStatus == null) {
      this.resourceStatus = null;
    } else {
      this.resourceStatus = new LinkedHashMap(resourceStatus);
    }
    return (A) this;
  }
  
  public boolean hasResourceStatus() {
    return this.resourceStatus != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubscriptionUnitStatusFluent that = (SubscriptionUnitStatusFluent) o;
    if (!java.util.Objects.equals(lastUpdateTime, that.lastUpdateTime)) return false;
    if (!java.util.Objects.equals(message, that.message)) return false;
    if (!java.util.Objects.equals(phase, that.phase)) return false;
    if (!java.util.Objects.equals(reason, that.reason)) return false;
    if (!java.util.Objects.equals(resourceStatus, that.resourceStatus)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(lastUpdateTime,  message,  phase,  reason,  resourceStatus,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (lastUpdateTime != null) { sb.append("lastUpdateTime:"); sb.append(lastUpdateTime + ","); }
    if (message != null) { sb.append("message:"); sb.append(message + ","); }
    if (phase != null) { sb.append("phase:"); sb.append(phase + ","); }
    if (reason != null) { sb.append("reason:"); sb.append(reason + ","); }
    if (resourceStatus != null && !resourceStatus.isEmpty()) { sb.append("resourceStatus:"); sb.append(resourceStatus); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> open-cluster-management-apps-model-6.13.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/SubscriptionUnitStatusFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SubscriptionUnitStatusFluent<A extends SubscriptionUnitStatusFluent<A>> extends BaseFluent<A>{
  public SubscriptionUnitStatusFluent() {
  }
  
  public SubscriptionUnitStatusFluent(SubscriptionUnitStatus instance) {
    this.copyInstance(instance);
  }
  private String lastUpdateTime;
  private String message;
  private String phase;
  private String reason;
  private Map<String,Object> resourceStatus;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(SubscriptionUnitStatus instance) {
    instance = (instance != null ? instance : new SubscriptionUnitStatus());
    if (instance != null) {
          this.withLastUpdateTime(instance.getLastUpdateTime());
          this.withMessage(instance.getMessage());
          this.withPhase(instance.getPhase());
          this.withReason(instance.getReason());
          this.withResourceStatus(instance.getResourceStatus());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getLastUpdateTime() {
    return this.lastUpdateTime;
  }
  
  public A withLastUpdateTime(String lastUpdateTime) {
    this.lastUpdateTime = lastUpdateTime;
    return (A) this;
  }
  
  public boolean hasLastUpdateTime() {
    return this.lastUpdateTime != null;
  }
  
  public String getMessage() {
    return this.message;
  }
  
  public A withMessage(String message) {
    this.message = message;
    return (A) this;
  }
  
  public boolean hasMessage() {
    return this.message != null;
  }
  
  public String getPhase() {
    return this.phase;
  }
  
  public A withPhase(String phase) {
    this.phase = phase;
    return (A) this;
  }
  
  public boolean hasPhase() {
    return this.phase != null;
  }
  
  public String getReason() {
    return this.reason;
  }
  
  public A withReason(String reason) {
    this.reason = reason;
    return (A) this;
  }
  
  public boolean hasReason() {
    return this.reason != null;
  }
  
  public A addToResourceStatus(String key,Object value) {
    if(this.resourceStatus == null && key != null && value != null) { this.resourceStatus = new LinkedHashMap(); }
    if(key != null && value != null) {this.resourceStatus.put(key, value);} return (A)this;
  }
  
  public A addToResourceStatus(Map<String,Object> map) {
    if(this.resourceStatus == null && map != null) { this.resourceStatus = new LinkedHashMap(); }
    if(map != null) { this.resourceStatus.putAll(map);} return (A)this;
  }
  
  public A removeFromResourceStatus(String key) {
    if(this.resourceStatus == null) { return (A) this; }
    if(key != null && this.resourceStatus != null) {this.resourceStatus.remove(key);} return (A)this;
  }
  
  public A removeFromResourceStatus(Map<String,Object> map) {
    if(this.resourceStatus == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.resourceStatus != null){this.resourceStatus.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getResourceStatus() {
    return this.resourceStatus;
  }
  
  public <K,V>A withResourceStatus(Map<String,Object> resourceStatus) {
    if (resourceStatus == null) {
      this.resourceStatus = null;
    } else {
      this.resourceStatus = new LinkedHashMap(resourceStatus);
    }
    return (A) this;
  }
  
  public boolean hasResourceStatus() {
    return this.resourceStatus != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubscriptionUnitStatusFluent that = (SubscriptionUnitStatusFluent) o;
    if (!java.util.Objects.equals(lastUpdateTime, that.lastUpdateTime)) return false;
    if (!java.util.Objects.equals(message, that.message)) return false;
    if (!java.util.Objects.equals(phase, that.phase)) return false;
    if (!java.util.Objects.equals(reason, that.reason)) return false;
    if (!java.util.Objects.equals(resourceStatus, that.resourceStatus)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(lastUpdateTime,  message,  phase,  reason,  resourceStatus,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (lastUpdateTime != null) { sb.append("lastUpdateTime:"); sb.append(lastUpdateTime + ","); }
    if (message != null) { sb.append("message:"); sb.append(message + ","); }
    if (phase != null) { sb.append("phase:"); sb.append(phase + ","); }
    if (reason != null) { sb.append("reason:"); sb.append(reason + ","); }
    if (resourceStatus != null && !resourceStatus.isEmpty()) { sb.append("resourceStatus:"); sb.append(resourceStatus + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
